==> krita-2.99.91.tar.xz: krita-2.99.91/plugins/paintops/libpaintop/kis_color_source_option_widget.h <==
/*
 * Copyright (c) 2011 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KIS_COLOR_SOURCE_OPTION_WIDGET_H
#define KIS_COLOR_SOURCE_OPTION_WIDGET_H

#include "kis_paintop_option.h"
#include <kritapaintop_export.h>

class KisPaintopLodLimitations;

/**
 * The brush option allows the user to select a particular brush
 * footprint for suitable paintops
 */
class PAINTOP_EXPORT KisColorSourceOptionWidget : public KisPaintOpOption
{
    Q_OBJECT
public:
    KisColorSourceOptionWidget();
    ~KisColorSourceOptionWidget();

    void writeOptionSetting(KisPropertiesConfiguration* setting) const;
    void readOptionSetting(const KisPropertiesConfiguration* setting);

    void lodLimitations(KisPaintopLodLimitations *l) const;

private Q_SLOTS:
    void sourceChanged();
private:
    struct Private;
    Private* const d;
};

#endif

==> krita_4.1.7+dfsg.orig.tar.xz: krita-4.1.7.101/plugins/paintops/libpaintop/kis_color_source_option_widget.h <==
/*
 * Copyright (c) 2011 Cyrille Berger <cberger@cberger.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KIS_COLOR_SOURCE_OPTION_WIDGET_H
#define KIS_COLOR_SOURCE_OPTION_WIDGET_H

#include "kis_paintop_option.h"
#include <kritapaintop_export.h>

class KisPaintopLodLimitations;

/**
 * The brush option allows the user to select a particular brush
 * footprint for suitable paintops
 */
class PAINTOP_EXPORT KisColorSourceOptionWidget : public KisPaintOpOption
{
    Q_OBJECT
public:
    KisColorSourceOptionWidget();
    ~KisColorSourceOptionWidget() override;

    void writeOptionSetting(KisPropertiesConfigurationSP setting) const override;
    void readOptionSetting(const KisPropertiesConfigurationSP setting) override;

    void lodLimitations(KisPaintopLodLimitations *l) const override;

private Q_SLOTS:
    void sourceChanged();
private:
    struct Private;
    Private* const d;
};

#endif
